@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ AkonadiMailTransportPlugin::AkonadiMailTransportPlugin(QObject *parent, const QL
     connect(AgentManager::self(), &AgentManager::typeRemoved, this, &AkonadiMailTransportPlugin::slotUpdatePluginList);
 }
 
-AkonadiMailTransportPlugin::~AkonadiMailTransportPlugin()
-{
-}
+AkonadiMailTransportPlugin::~AkonadiMailTransportPlugin() = default;
 
 void AkonadiMailTransportPlugin::slotUpdatePluginList(const Akonadi::AgentType &type)
 {
